@@ -1,4 +1,4 @@
-/* X11::GUITest ($Id: GUITest.h,v 1.14 2011/01/06 18:43:58 ctrondlp Exp $)
+/* X11::GUITest ($Id: GUITest.h,v 1.17 2011/04/25 03:27:25 ctrondlp Exp $)
  *  
  * Copyright (c) 2003-2011 Dennis K. Paulsen, All Rights Reserved.
  * Email: ctrondlp@cpan.org
@@ -14,26 +14,13 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * along with this program; if not, see <http://www.gnu.org/licenses>.
  *
  */
 #ifndef GUITest_h
 #define GUITest_h
 
 
-#ifndef BOOL
-#define BOOL int
-#endif
-#ifndef UINT
-#define UINT unsigned int
-#endif
-#ifndef ULONG
-#define ULONG unsigned long
-#endif
-
-#define NUL '\0'
-
 #define DEF_EVENT_SEND_DELAY 10 /* Value < 10 not recommended */
 #define DEF_KEY_SEND_DELAY 0 
 #define KEYMAP_VECTOR_SIZE 32
@@ -46,11 +33,6 @@ typedef struct WindowTable {
 	UINT Max;
 } WindowTable;
 
-typedef struct KeyNameSymTable {
-	char *Name; 
-	KeySym Sym;
-} KeyNameSymTable;
-
 
 #endif /* #ifndef GUITest_h */
 
